==> haskell-vector-th-unbox-0.2.1.6-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vector-th-unbox.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-th-unbox
version: 0.2.1.6
id: vector-th-unbox-0.2.1.6-5wEe6hRA1hMRE4Y3gV5Tw
key: vector-th-unbox-0.2.1.6-5wEe6hRA1hMRE4Y3gV5Tw
license: BSD-3-Clause
copyright: © 2012−2015 Liyang HU
maintainer: Liyang HU <vector-th-unbox@liyang.hu>
author: Liyang HU <vector-th-unbox@liyang.hu>
stability: experimental
synopsis: Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.
    .
    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.
category: Data
abi: 8f69a3d65bc98dbbc58625401f1b4c42
exposed: True
exposed-modules:
    Data.Vector.Unboxed.Deriving
import-dirs: /usr/lib/ghc-8.4.3/site-local/vector-th-unbox-0.2.1.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/vector-th-unbox-0.2.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/vector-th-unbox-0.2.1.6
hs-libraries: HSvector-th-unbox-0.2.1.6-5wEe6hRA1hMRE4Y3gV5Tw
depends:
    base-4.11.1.0 template-haskell-2.13.0.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock
haddock-html: /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-th-unbox-0.2.1.6-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vector-th-unbox.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-th-unbox
version: 0.2.1.6
id: vector-th-unbox-0.2.1.6-J8CuseO2OKiARtdHxtybxq
key: vector-th-unbox-0.2.1.6-J8CuseO2OKiARtdHxtybxq
license: BSD-3-Clause
copyright: © 2012−2015 Liyang HU
maintainer: Liyang HU <vector-th-unbox@liyang.hu>
author: Liyang HU <vector-th-unbox@liyang.hu>
stability: experimental
synopsis: Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.
    .
    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.
category: Data
abi: 75e07cc088f55ddf364099a73ecc565e
exposed: True
exposed-modules:
    Data.Vector.Unboxed.Deriving
import-dirs: /usr/lib/ghc-8.6.1/site-local/vector-th-unbox-0.2.1.6
library-dirs: /usr/lib/ghc-8.6.1/site-local/vector-th-unbox-0.2.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/vector-th-unbox-0.2.1.6
hs-libraries: HSvector-th-unbox-0.2.1.6-J8CuseO2OKiARtdHxtybxq
depends:
    base-4.12.0.0 template-haskell-2.14.0.0
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock
haddock-html: /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
